function [t0real, t0realErr, t0imag, t0imagErr, LJ, LJerr, Lc, LcErr] ...
    = Fit_DelAlpha_vs_CoGdThick_complext0_expdec_v1loop_fixTGratio(g1, g2, Lsf, rho, ratio, phaseGuess, LJguess, fileName, pathName)
%   g1 = spin mixing conductance at Py/Cu interface (nm^-2)
%   g2 = (saturated) spin mixing conductance at Cu/CoGd interface (nm^-2)
%   Lsf = transverse spin flip length (nm)
%   rho = resistivity of FM spin sink (Ohm m)
%   ratio = ratio of |interfacial transmission mixing conductance| to spin mixing conductance g2 

close all

%[fileName,pathName,filterIndex] = uigetfile('C:\Users\semori\Documents\MATLAB\Spin Pumping FM sink (comp t0 + exp decay)\*.dat', 'All Files');

% read in data while ignoring header
fid = fopen([pathName, '\', fileName]);

data = textscan(fid,'%f %f %f','HeaderLines',0,'Delimiter','\t','CollectOutput', 1);
data = data{1};
fclose(fid);
%data = sortrows(data);
t = data(:,1); %thickness
a = data(:,2); %damping enhancement
aErr = data(:,3); %damping enhancement error

weights = 1./aErr.^2; % weights for fitting, inversely proportional to errorbar squared

% prompt={'min x plot (nm) ', 'max x plot (nm) ', 'min y plot ', 'max y plot '};
% defaultans = {'0', '15', '-0.25e-3', '3.25e-3'};
% dlg_title='plot range'; 
% num_lines = 1;
% answer = inputdlg(prompt,dlg_title,num_lines,defaultans);
xmin = 0; %str2num(answer{1}); 
xmax = 15; %str2num(answer{2});
ymin = -0.25e-3; %str2num(answer{3});
ymax = 3.25e-3; %str2num(answer{4});

%DeltaAlphaPy_CoGdSS(g1, g2, t0real, t0imag, d2, Lsf, LJ, rho)

% b(1): 
% real part of interfacial transmission mixing conductance,
% t0ireal (nm^-2) = ratio*cos(b(1)) 
% imaginary part of interfacial transmission mixing
% conductance, t0imag (nm^-2) = ratio*sin(b(1))

% b(2) = spin dephasing length, LJ (nm) 
func = @(b,x)DeltaAlphaPy_CoGdSS(g1, g2, ratio.*g2.*cos(b(1)), ratio.*g2.*sin(b(1)), x, Lsf, b(2), rho);

% initial guess values 
start = [phaseGuess, LJguess];

t0rGuess = ratio*g2*cos(phaseGuess);
t0iGuess = ratio*g2*sin(phaseGuess);

% fit data to the linear function
nlm = NonLinearModel.fit(t,a,func,start, 'Weights', weights);

coeff = nlm.Coefficients.Estimate; % extract coeffients in fit function
coeffErr = nlm.Coefficients.SE; % extract standard errors for coefficients

r2ord = nlm.Rsquared.Ordinary; % ordinary R-squared value for the fit
r2adj = nlm.Rsquared.Adjusted; % adjusted R-squared value for the fit

g1Err = 0;
g2Err = 0;
LsfErr = 0;
rhoErr = 0;

% interfacial transmission mixing conductance & its error extracted from the fit
t0real = ratio*g2*cos(coeff(1));
t0realUB = ratio*g2*cos(coeff(1)+coeffErr(1));
t0realLB = ratio*g2*cos(coeff(1)-coeffErr(1));
t0realErr = abs(t0realUB-t0realLB)/2;

t0imag = ratio*g2*sin(coeff(1)); 
t0imagUB = ratio*g2*sin(coeff(1)+coeffErr(1));
t0imagLB = ratio*g2*sin(coeff(1)-coeffErr(1));
t0imagErr = abs(t0imagUB-t0imagLB)/2;


% spin dephasing length & its error extracted from the fit
LJ = coeff(2); 
LJerr = coeffErr(2);

% transverse spin coherence (penetration) length
Lc = (real(1./Lplus(Lsf, LJ))).^-1;
LcUB = (real(1./Lplus(Lsf, LJ+LJerr))).^-1;
LcLB = (real(1./Lplus(Lsf, LJ-LJerr))).^-1;
LcErr = (LcUB-LcLB)/2;

max_t_plot = 15; 
x_fit_plot = 0:0.05:max_t_plot;
y_fit_mid = DeltaAlphaPy_CoGdSS(g1, g2, t0real, t0imag, x_fit_plot, Lsf, LJ, rho);
y_fit_init = DeltaAlphaPy_CoGdSS(g1, g2, t0rGuess, t0iGuess, x_fit_plot, Lsf, LJguess, rho);

titleString = strvcat(fileName, ...
    ['g^{\uparrow\downarrow}_1 = ', num2str(g1,'%0.1f'), ' \pm ', num2str(g1Err,'%0.1f'), ' nm^{-2}, ', ...
    'g^{\uparrow\downarrow}_2 = ', num2str(g2,'%0.1f'), ' \pm ', num2str(g2Err,'%0.1f'), ' nm^{-2}, '], ...
    ['t^{\uparrow\downarrow}_{0,r} = ', num2str(t0real,'%0.1f'), ' \pm ', num2str(t0realErr,'%0.1f'), ' nm^{-2}, ', ...
    't^{\uparrow\downarrow}_{0,i} = ', num2str(t0imag,'%0.1f'), ' \pm ', num2str(t0imagErr,'%0.1f'), ' nm^{-2}'], ...
    ['L_{sf} = ', num2str(Lsf,'%0.2f'), ' \pm ', num2str(LsfErr,'%0.2f'), ' nm, ', ...
    'L_J = ', num2str(LJ,'%0.2f'), ' \pm ', num2str(LJerr,'%0.2f'), ' nm, ', ...
    'L_c = ', num2str(Lc,'%0.2f'), ' \pm ', num2str(LcErr,'%0.2f'), ' nm'], ...
    ['\rho = ', num2str(rho,'%0.2e'), ' \pm ', num2str(rhoErr,'%0.2e'), ' \Omega m'], ...
     ['ratio = ',  num2str(ratio,'%0.2f'), ', t^{\uparrow\downarrow}_{0,r} (init) = ', num2str(t0rGuess,'%0.1f'), ' nm^{-2}, ', ...
    't^{\uparrow\downarrow}_{0,i} (init) = ', num2str(t0iGuess,'%0.1f'), ' nm^{-2}, ', ...
    'L_{J} (init) = ', num2str(LJguess,'%0.1f'), ' nm'], ...
    ['ordinary R^2 = ', num2str(r2ord,'%0.3f'), ', adj. R^2 = ', num2str(r2adj,'%0.3f')], ...
    ['_']);

% plot experimental data and fit curve
h = figure;
errorbar(t, a, aErr, 'ko',  'MarkerSize', 10); 
xlim([xmin xmax]);
ylim([ymin ymax]);
xlabel('spin sink thickness (nm)', 'FontSize', 10);
ylabel('\Delta\alpha', 'FontSize', 10);
title(titleString, 'FontSize', 7);

hold on;
plot(x_fit_plot, y_fit_init, 'k--', 'LineWidth', 1);
plot(x_fit_plot, y_fit_mid, 'k-', 'LineWidth', 3);
plot([LJ LJ], [ymin ymax],  'b-', 'LineWidth', 1); 
plot([LJ+LJerr LJ+LJerr], [ymin ymax],  'b--', 'LineWidth', 0.5); 
plot([LJ-LJerr LJ-LJerr], [ymin ymax],  'b--', 'LineWidth', 0.5); 
plot([Lsf Lsf], [ymin ymax],  'r-', 'LineWidth', 1);
plot([Lc Lc], [ymin ymax],  'g-', 'LineWidth', 2); 
plot([Lc+LcErr Lc+LcErr], [ymin ymax],  'g--', 'LineWidth', 1); 
plot([Lc-LcErr Lc-LcErr], [ymin ymax],  'g--', 'LineWidth', 1); 

fileString = [pathName, '\', fileName, '-v1fixRatio-g1', num2str(g1,'%0.1f'), '-g2', num2str(g2,'%0.1f'), '-Lsf', num2str(Lsf,'%0.1f'), '-rho', num2str(rho,'%0.2e'), ...
    '-ratio', num2str(ratio,'%0.2f'), '-t0rIn', num2str(t0rGuess,'%0.1f'), '-t0iIn', num2str(t0iGuess,'%0.1f'), '-LJin', num2str(LJguess,'%0.1f')];

saveas(h, [fileString, '.png']); 

fitOutput = [x_fit_plot.', y_fit_mid.', y_fit_init.']; %, y_fit_ub.', y_fit_lb.'];
            fidOut = fopen([fileString, '.dat'],'wt');
            fprintf(fidOut, '%s\t %s\t %s\n', 'd2', 'fit', 'initGuess');
            fprintf(fidOut, '%6.2f %0.6f %0.6f\n', fitOutput');
            %fprintf(fidOut, '%s\t %s\t %s\t %s\n', 't', 'midpt', 'upbound', 'lowbound');
            %fprintf(fidOut, '%6.2f %0.6f %0.6f %0.6f\n', fitOutput');
            fclose(fidOut);
hold off;


% plot real and imaginary components of interfacial transmitted mixing
% condutance
h2 = figure;
xlim([xmin xmax]);
%ylim([-18 18]);
xlabel('spin sink thickness (nm)', 'FontSize', 10);
ylabel('t^{\uparrow\downarrow}_{0,(r,i)} (nm^{-2})', 'FontSize', 10);
title(titleString, 'FontSize', 7);
hold on;

t0comp = TransMixCond_complex_t0_expdecay(t0real, t0imag, x_fit_plot, Lsf, LJ);
t0real_plot = real(t0comp);
t0imag_plot = imag(t0comp);

t0max = max(abs(t0comp));
ylim([-1.1*t0max 1.1*t0max]);

plot(x_fit_plot, t0real_plot, 'k-', 'LineWidth', 2);
plot(x_fit_plot, t0imag_plot, 'k--', 'LineWidth', 2);
plot([LJ LJ], [-1.1*t0max 1.1*t0max],  'b-', 'LineWidth', 1); 
plot([LJ+LJerr LJ+LJerr], [-1.1*t0max 1.1*t0max],  'b--', 'LineWidth', 0.5); 
plot([LJ-LJerr LJ-LJerr], [-1.1*t0max 1.1*t0max],  'b--', 'LineWidth', 0.5); 
plot([Lsf Lsf], [-1.1*t0max 1.1*t0max],  'r-', 'LineWidth', 1);
plot([Lc Lc], [-1.1*t0max 1.1*t0max],  'g-', 'LineWidth', 2); 
plot([Lc+LcErr Lc+LcErr], [-1.1*t0max 1.1*t0max],  'g--', 'LineWidth', 1); 
plot([Lc-LcErr Lc-LcErr], [-1.1*t0max 1.1*t0max],  'g--', 'LineWidth', 1); 

saveas(h2, [fileString, '-t0.png']); 

t0Output = [x_fit_plot.', t0real_plot.', t0imag_plot.']; 
            fidOut = fopen([fileString, '-t0.dat'],'wt');
            fprintf(fidOut, '%s\t %s\t %s\n', 'd2', 't0real', 't0imag');
            fprintf(fidOut, '%6.2f %0.6f %0.6f\n', t0Output');
            fclose(fidOut);
hold off;

end





