function complexVal = K1(t0real, t0imag, d2, Lsf, LJ, rho)
% from Eq. 11 in Taniguchi et al. IEEE Trans. Magn. 44, 2636 (2008)
%   t0 = interfacial contribution to transmission mixing conductance
%   (nm^-2)
%   d2 = FM spin sink thickness (nm)
%   Lsf = transverse spin flip length (nm)
%   LJ = spin dephasing length (nm)
%   rho = resistivity of FM spin sink (Ohm m)

tComp = TransMixCond_complex_t0_expdecay(t0real, t0imag, d2, Lsf, LJ); % complex transmission mixing conductance
tReal = real(tComp); % real part of transmission mixing conductance
tImag = imag(tComp); % imaginary part of transmission mixing conductance

etaComp = eta(d2, Lsf, LJ, rho); 
etaReal = real(etaComp);
etaImag = imag(etaComp);

complexVal = 1 + tReal.*etaReal + tImag.*etaImag;  

end
